@@ -1,21 +1,12 @@
 import logging
 
 
-
-
-
 log = logging.getLogger("").getChild(__name__)
 
 
-
-
 class CommandBase:
 
-    def __init__(
-        self, *args, **kwargs
-    ) -> None:
-        ...
-
+    def __init__(self, *args, **kwargs) -> None: ...
 
     def do_run(self):
 
@@ -23,4 +14,3 @@ class CommandBase:
 
     def run(self):
         pass
-
